from PySide6.QtGui import QGuiApplication, QAction
from PySide6.QtQml import QQmlApplicationEngine
from PySide6 import QtWidgets, QtCore
from PySide6.QtWidgets import QVBoxLayout, QFormLayout, QLineEdit, QHBoxLayout, QPushButton, QDialog

from models.member import Member

from database.member import create_new_member


class MemberEditor(QDialog):
    def __init__(self, member: Member = None):
        super().__init__()

        self.create_layout()

        if member:
            self.member = member
            self.fill_with_existing_data()
            self.create_new = False
        else:
            self.member = Member()
            self.create_new = True

    def create_layout(self):
        self.setWindowTitle("Members")
        self.setMinimumSize(400, 300)

        # Create main layout
        self.layout = QVBoxLayout(self)

        # Form layout for member fields
        self.form_layout = QFormLayout()

        # First name field
        self.first_name_input = QLineEdit()
        self.form_layout.addRow("First name:", self.first_name_input)

        # Last name field
        self.last_name_input = QLineEdit()
        self.form_layout.addRow("Last name: ", self.last_name_input)

        # E-mail field
        self.email_input = QLineEdit()
        self.form_layout.addRow("E-mail:", self.email_input)

        # Phone number
        self.phone_number_input = QLineEdit()
        self.form_layout.addRow("Phone number:", self.phone_number_input)

        self.layout.addLayout(self.form_layout)

        # Buttons
        self.button_layout = QHBoxLayout()

        self.save_button = QPushButton("Save")
        self.save_button.clicked.connect(self.save_member)
        self.button_layout.addWidget(self.save_button)

        self.cancel_button = QPushButton("Discard")
        self.cancel_button.clicked.connect(self.reject)
        self.button_layout.addWidget(self.cancel_button)

        self.layout.addLayout(self.button_layout)

    def fill_with_existing_data(self):
        self.first_name_input.setText(self.member.first_name)
        self.last_name_input.setText(self.member.last_name)
        self.email_input.setText(self.member.email)
        self.phone_number_input.setText(self.member.phone)

    def save_member(self):
        self.member.first_name = self.first_name_input.text()
        self.member.last_name = self.last_name_input.text()
        self.member.email = self.email_input.text()
        self.member.phone = self.phone_number_input.text()

        if self.create_new:
            create_new_member(self.member)

        self.accept()